@@ -2,6 +2,7 @@ import importlib
 import json
 import re
 import os
+import logging
 import webob
 import yaml
 from aalam_common import wsgi, auth as zauth
@@ -63,6 +64,8 @@ class Hooks(wsgi.Middleware):
         except Exception:
             raise webob.exc.HTTPBadRequest(
                 explanation="Input content not proper")
+
+        logging.debug("Adding %d hooks" % len(hooks))
         for h in hooks:
             url_key = self._frame_url_key(h)
             final_type = ""
@@ -97,12 +100,19 @@ class Hooks(wsgi.Middleware):
             "(" + '$)|('.join(self._hooks_map.keys()) + "$)")
         return webob.response.Response(status=200)
 
+    def log_hooks(self, request):
+        # This is just for logging purposes.
+        logging.debug("Hooks map %s" % self._hooks_map)
+        logging.debug("Hooks regex %s" % (self._regex and self._regex.pattern))
+
     def delete_hook(self, request):
         try:
             hooks = request.json
         except Exception:
             raise webob.exc.HTTPBadRequest(
                 explanation="Input content not proper")
+
+        logging.debug("Removing %d hooks" % len(hooks))
         for h in hooks:
             url_key = self._frame_url_key(h)
             if url_key not in self._hooks_map:
@@ -218,8 +228,9 @@ class Hooks(wsgi.Middleware):
                         'params': params,
                         'data': request.text}
                 kwargs = {'json': data}
-                if request.auth and 'email_id' in request.auth:
-                    kwargs['user'] = request.auth['email_id']
+                if request.auth and request.auth.get('user'):
+                    kwargs['user'] = request.auth.get(
+                        'email_id', request.auth.get('mobile', None))
                 try:
                     resp = zutils.request_local_server(
                         'POST',
@@ -264,8 +275,9 @@ class Hooks(wsgi.Middleware):
                         'data': hook_data,
                         }
                 kwargs = {'json': data}
-                if 'email_id' in request.auth:
-                    kwargs['user'] = request.auth['email_id']
+                if request.auth and request.auth.get('user'):
+                    kwargs['user'] = request.auth.get(
+                        'email_id', request.auth.get('mobile', None))
                 try:
                     zutils.request_local_server(
                         'POST',
@@ -291,11 +303,16 @@ class Hooks(wsgi.Middleware):
                 return self.delete_hook(request)
             elif request.method == 'POST':
                 return self.hook_callback(request)
+            elif request.method == 'GET':
+                return self.log_hooks(request)
             else:
                 raise webob.exc.HTTPNotFound(
                     explanation="Invalid method(%s)" % request.method)
         if request.is_nohook:
             avoid_cb_of_app = zauth.is_auth_internal(request)
+            if not avoid_cb_of_app:
+                # from another source, so, ignore completely
+                return
 
         return self.process_hooks_b(request, avoid_cb_of_app)
 
@@ -303,5 +320,8 @@ class Hooks(wsgi.Middleware):
         avoid_cb_of_app = None
         if request.is_nohook:
             avoid_cb_of_app = zauth.is_auth_internal(request)
+            if not avoid_cb_of_app:
+                # from another source, so, ignore completely
+                return response
 
         return self.process_hooks_a(request, response, avoid_cb_of_app)
