@@ -46,7 +46,7 @@ app_callbacks = {}
 
 class AALAMRequest(webob.Request):
     def __repr__(self):
-        return "AALAMRequest at %x" % self
+        return "AALAMRequest at %x" % id(self)
 
     def _filterout_system_params(self):
         if '_is_nohook' not in self.environ['webob.adhoc_attrs']:
